@@ -650,7 +650,7 @@ int DataBase::scanFsToNode(QString *what,Node *to)
      i = 1 + (QMessageBox::warning(NULL,tr("Error"),errormsg,tr("Ignore directory"),tr("Cancel scanning")));     
      return i;
    }
-  dirlist = dir->entryInfoList();
+  dirlist = dir->entryInfoList("*", QDir::All|QDir::Hidden|QDir::System);
   QFileInfoListIterator it(*dirlist);
   QFileInfo *fileInfo;
   
