@@ -114,20 +114,6 @@ ImportDialog::ImportDialog( QWidget* parent, const char* name, bool modal, WFlag
 	separator_lineedit->setEnabled(false);
 
 	
-
-	// tmp
-	/*
-	importTypeCsv->setChecked(true);
-	separator_lab->setEnabled(true);
-	separator_lineedit->setEnabled(true);
-	//filename_lineedit->setText("c:\\devel\\mp3s.csv");
-	filename_lineedit->setText("/data3/res3/musikvideo.csv");
-	separator_lineedit->setText("*");
-	correctbadstyle->setEnabled(true);
-	correctbadstyle->setChecked(true);
-	*/
-	// tmp
-	//filename_lineedit->setText("/home/crissi/compile/cvs/CdCat-0.98pre_whereisit_xml_import/sample-export.xml");
 	filename_lineedit->setText("");
 
 }
@@ -205,9 +191,7 @@ int ImportDialog::bOk( void ) {
 		type = 1;
 	if ( importTypeWhereisitXml->isChecked() )
 		type = 2;
-		
 	OK = 1;
-		
 	close();
 	return 0;
 }
