@@ -22,6 +22,7 @@ Copyright : (C) 2003 Christoph Thielecke
 #include <qbuttongroup.h>
 
 
+
 class QLabel;
 class QLineEdit;
 class QPushButton;
@@ -35,22 +36,27 @@ public:
 
 
 	QLabel* filename_lab;
-	QLabel* seperator_lab;
+	QLabel* separator_lab;
 	QLabel* info_lab;
 
 	QPushButton* buttonCancel;
 	QPushButton* buttonOK;
 	QPushButton* buttonGetFile;
 	QLineEdit* filename_lineedit;
-	QLineEdit* seperator_lineedit;
+	QLineEdit* separator_lineedit;
 	QCheckBox *newdatabase;
 	QCheckBox *correctbadstyle;
-	QRadioButton *importTypeText;
-	QRadioButton *importTypeXml;
+	QRadioButton *importTypeCsv;
+	QRadioButton *importTypeGtktalogXml;
+	QRadioButton *importTypeWhereisitXml;
 	QButtonGroup *importButtonBox;
 
 
 protected:
+	QGridLayout* layout4;
+	QGridLayout* ImportDialogLayout;
+	QVBoxLayout* type_layout;
+	QHBoxLayout* csv_layout;
 
 protected slots:
 	virtual void languageChange();
@@ -64,7 +70,7 @@ private:
 
 public:
 	int OK;
-	QString filename, seperator;
+	QString filename, separator;
 	bool createdatabase;
 	int type;
 
