@@ -79,7 +79,7 @@ InfoDialog::InfoDialog( QWidget* parent, const char* name, bool modal, WFlags fl
     infotext+=VERSION;
     infotext+="</h2><br>\n";
     infotext+=tr("Author:");
-    infotext+="<br><font size=\"+2\">Peter Deak (hyperr@freemail.hu)<br></font><br>\n";
+    infotext+="<br><font size=\"+2\"><b>Peter Deak (hyperr@freemail.hu)</b><br></font><br>\n";
     infotext+=tr("Copyright (C) 2003 Peter Deak (GPL)");
     infotext+="</p></font></p>";
 
@@ -88,6 +88,12 @@ InfoDialog::InfoDialog( QWidget* parent, const char* name, bool modal, WFlags fl
     contribution +=   "Christoph Thielecke (crissi99@gmx.de)";
     contribution +=   "</b></font><br>\n";
     contribution +=   tr("German translation & additional programming");
+
+    contribution +=   "<br>";
+    contribution +=   "<p align=\"center\"><font size=\"+2\"><b>";
+    contribution +=   "Techno (techno@punkt.pl)";
+    contribution +=   "</b></font><br>\n";
+    contribution +=   tr("AVI reader plugin & Polish translation");
     
     contribution +=   "<br><br>";
     contribution +=   "<p align=\"center\"><font size=\"+1\"><b>";
@@ -101,11 +107,8 @@ InfoDialog::InfoDialog( QWidget* parent, const char* name, bool modal, WFlags fl
     contribution +=   "</b></font><br>\n";
     contribution +=   tr("Czech translation");
 
-    contribution +=   "<br>";
-    contribution +=   "<p align=\"center\"><font size=\"+1\"><b>";
-    contribution +=   "Techno (techno@punkt.pl)";
-    contribution +=   "</b></font><br>\n";
-    contribution +=   tr("Polish translation");
+    contribution +=    "<br>\n";
+    contribution +=    "</p>\n";
 
     contribution +=    "</p>\n";
 /******************************************************************************************/
