@@ -25,8 +25,8 @@
  *
  *Copyright Piotr "|TEcHNO|" Lewandowski, 2004
  */
-//#include <iostream> for debug only
-#include <stdio.h>
+//#include <iostream.h>
+//#include <stdio.h>
 #include <malloc.h>
 #include <qstring.h>
 
@@ -233,7 +233,7 @@ struct WAVEFORMATEX{
 	} waveH;
 
 /*
- *All of these well be null-treminated 
+ *All of these will be null-treminated 
  *(or some strange sequence-terminated)
  */
 struct INFOLIST{
@@ -560,7 +560,11 @@ QString parseAviHeader(FILE* file){
 	ReturnData+="\n";	
 	fourccSwitch(strfFourCC.hex, ReturnData);
 	
-	ReturnData+=QObject::tr("Total Time") + QString(" = %1:%2:%3\n").arg((unsigned long)((float)avih.dwTotalFrames/_FPS)/3600,2,10).arg((unsigned long)((float)avih.dwTotalFrames/_FPS)/60,2,10).arg((unsigned long)((float)avih.dwTotalFrames/_FPS)%60,2,10);
+	ReturnData+=QObject::tr("Total Time") + QString(" = %1:%2:%3\n").arg((unsigned long)((float)avih.dwTotalFrames/_FPS)/3600,2,10).arg(((unsigned long)((float)avih.dwTotalFrames/_FPS)/60)%60,2,10).arg((unsigned long)((float)avih.dwTotalFrames/_FPS)%60,2,10);
+//	cout << "|0" <<
+//	printf("%.2lu:%.2lu:%.2lu",(unsigned long)((float)avih.dwTotalFrames/_FPS)/3600,// << ":" << /*((unsigned long)((float)avih.dwTotalFrames/_FPS)/60ul)<10?"0":"" <<*/
+//	((unsigned long)((float)avih.dwTotalFrames/_FPS)/60)%60,//< ":" << /*((unsigned long)((float)avih.dwTotalFrames/_FPS)%60)<ul10?"0":"" <<*/
+//	(unsigned long)((float)avih.dwTotalFrames/_FPS)%60) ;
 	ReturnData+=QObject::tr("Framerate")  + QString(" = %1 f/s\n").arg(_FPS,0,'f',3);
 	ReturnData+=QObject::tr("Resolution") + QString(" = %1x%2\n").arg(avih.dwWidth).arg(avih.dwHeight);
 	ReturnData+="\n";
